@@ -406,9 +406,13 @@ class Jira(AtlassianRestAPI):
         :return:
         """
         url = 'rest/api/2/group/member'
-        url += "?groupname={group}&includeInactiveUsers={include_inactive}&startAt={start}&maxResults={limit}".format(
-            group=group, include_inactive=include_inactive_users, start=start, limit=limit)
-        return self.get(url)
+        params = {}
+        if group:
+            params['groupname'] = group
+        params['includeInactiveUsers'] = include_inactive_users
+        params['startAt'] = start
+        params['maxResults'] = limit
+        return self.get(url, params=params)
 
     def add_user_to_group(self, username, group_name):
         """
@@ -862,3 +866,16 @@ class Jira(AtlassianRestAPI):
         headers = self.form_token_headers
         url = 'rest/tempo-accounts/1/export'
         return self.get(url, headers=headers, not_json_response=True)
+
+    def health_check(self):
+        """
+        Get health status
+        https://confluence.atlassian.com/jirakb/how-to-retrieve-health-check-results-using-rest-api-867195158.html
+        :return:
+        """
+        # check as Troubleshooting & Support Tools Plugin
+        response = self.get('rest/troubleshooting/1.0/check/')
+        if not response:
+            # check as support tools
+            response = self.get('rest/supportHealthCheck/1.0/check/')
+        return response
